#!/usr/bin/env python
# Slightly modified version of Gears Installation script for debugging purposes.

import re
import sys

print "Python Version=[%s]"%sys.version
print
print "Path=[%s]"%sys.path
print

# Index of error string in InstallationCheck.strings
SAFARI_LESSTHAN_311_ERROR = 16
MIN_SAFARI_VERSION = [3, 1, 1]

# Match strings like 3.1.1 from the start of the string.
VERSION_MATCH_RE = re.compile(r'^\s*([\d\.]+)')

def safari_311_or_later():
  """Extract the full version string from Safari's Info.plist and return false
     if the currently installed version is < MIN_SAFARI_VERSION.
     
     We need to parse this string rather than relying on something simpler
     because there is a bug in certain versions of Safari where the other
     version strings in Info.plist are incorrect.
  """
  try:
    import plistlib
    safari_info_plist_path = '/Applications/Safari.app/Contents/Info.plist'
    safari_info_plist = plistlib.Plist.fromFile(safari_info_plist_path)
    get_info_version = safari_info_plist['CFBundleGetInfoString']
    print "get_info_version=(%s)"%(get_info_version)
    # Split off version string, get_info_version looks like:
    # '3.1.1, ....' so we slurp numbers and '.'s from the start of the string.
    version_str = VERSION_MATCH_RE.search(get_info_version).groups(0)[0]
    installed_version_num_array = version_str.split('.') # ['3','1','1']

    # Compare version numbers.
    for idx, numeral in enumerate(installed_version_num_array):
      numeral = int(numeral)
      if numeral < MIN_SAFARI_VERSION[idx]:
        return False
      elif numeral > MIN_SAFARI_VERSION[idx]:
        print "Safari Version OK"
        return True
  
  except Exception, e:
    print "Caught exception: ", e
    return False
  return True


def main():
  if (safari_311_or_later()):
    sys.exit(0) #Success!
  else:
    exit_val = (1 << 6) | ( 1 << 5 ) | SAFARI_LESSTHAN_311_ERROR
    sys.exit(exit_val);

if __name__ == "__main__":
  main()
